==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/AddHeader.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.Alignment;

@JsonPropertyOrder({
    "@odata.type", 
    "margin", 
    "alignment"})
@JsonInclude(Include.NON_NULL)
public class AddHeader extends MarkContent implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("margin")
    protected Integer margin;

    @JsonProperty("alignment")
    protected Alignment alignment;

    protected AddHeader() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.addHeader";
    }

    @Property(name="margin")
    @JsonIgnore
    public Optional<Integer> getMargin() {
        return Optional.ofNullable(margin);
    }

    public AddHeader withMargin(Integer margin) {
        AddHeader _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.addHeader");
        _x.margin = margin;
        return _x;
    }

    @Property(name="alignment")
    @JsonIgnore
    public Optional<Alignment> getAlignment() {
        return Optional.ofNullable(alignment);
    }

    public AddHeader withAlignment(Alignment alignment) {
        AddHeader _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.addHeader");
        _x.alignment = alignment;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAddHeader() {
        return new Builder();
    }

    public static final class Builder {
        private String name;
        private Long fontSize;
        private String text;
        private String fontColor;
        private Integer margin;
        private Alignment alignment;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder fontSize(Long fontSize) {
            this.fontSize = fontSize;
            this.changedFields = changedFields.add("fontSize");
            return this;
        }

        public Builder text(String text) {
            this.text = text;
            this.changedFields = changedFields.add("text");
            return this;
        }

        public Builder fontColor(String fontColor) {
            this.fontColor = fontColor;
            this.changedFields = changedFields.add("fontColor");
            return this;
        }

        public Builder margin(Integer margin) {
            this.margin = margin;
            this.changedFields = changedFields.add("margin");
            return this;
        }

        public Builder alignment(Alignment alignment) {
            this.alignment = alignment;
            this.changedFields = changedFields.add("alignment");
            return this;
        }

        public AddHeader build() {
            AddHeader _x = new AddHeader();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.addHeader";
            _x.name = name;
            _x.fontSize = fontSize;
            _x.text = text;
            _x.fontColor = fontColor;
            _x.margin = margin;
            _x.alignment = alignment;
            return _x;
        }
    }

    private AddHeader _copy() {
        AddHeader _x = new AddHeader();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.name = name;
        _x.fontSize = fontSize;
        _x.text = text;
        _x.fontColor = fontColor;
        _x.margin = margin;
        _x.alignment = alignment;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AddHeader[");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("fontSize=");
        b.append(this.fontSize);
        b.append(", ");
        b.append("text=");
        b.append(this.text);
        b.append(", ");
        b.append("fontColor=");
        b.append(this.fontColor);
        b.append(", ");
        b.append("margin=");
        b.append(this.margin);
        b.append(", ");
        b.append("alignment=");
        b.append(this.alignment);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/AddHeader.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.Alignment;

@JsonPropertyOrder({
    "@odata.type", 
    "alignment", 
    "margin"})
@JsonInclude(Include.NON_NULL)
public class AddHeader extends MarkContent implements ODataType {

    @JsonProperty("alignment")
    protected Alignment alignment;

    @JsonProperty("margin")
    protected Integer margin;

    protected AddHeader() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.addHeader";
    }

    @Property(name="alignment")
    @JsonIgnore
    public Optional<Alignment> getAlignment() {
        return Optional.ofNullable(alignment);
    }

    public AddHeader withAlignment(Alignment alignment) {
        AddHeader _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.addHeader");
        _x.alignment = alignment;
        return _x;
    }

    @Property(name="margin")
    @JsonIgnore
    public Optional<Integer> getMargin() {
        return Optional.ofNullable(margin);
    }

    public AddHeader withMargin(Integer margin) {
        AddHeader _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.addHeader");
        _x.margin = margin;
        return _x;
    }

    public AddHeader withUnmappedField(String name, Object value) {
        AddHeader _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAddHeader() {
        return new Builder();
    }

    public static final class Builder {
        private String name;
        private String fontColor;
        private Long fontSize;
        private String text;
        private Alignment alignment;
        private Integer margin;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder fontColor(String fontColor) {
            this.fontColor = fontColor;
            this.changedFields = changedFields.add("fontColor");
            return this;
        }

        public Builder fontSize(Long fontSize) {
            this.fontSize = fontSize;
            this.changedFields = changedFields.add("fontSize");
            return this;
        }

        public Builder text(String text) {
            this.text = text;
            this.changedFields = changedFields.add("text");
            return this;
        }

        public Builder alignment(Alignment alignment) {
            this.alignment = alignment;
            this.changedFields = changedFields.add("alignment");
            return this;
        }

        public Builder margin(Integer margin) {
            this.margin = margin;
            this.changedFields = changedFields.add("margin");
            return this;
        }

        public AddHeader build() {
            AddHeader _x = new AddHeader();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.addHeader";
            _x.name = name;
            _x.fontColor = fontColor;
            _x.fontSize = fontSize;
            _x.text = text;
            _x.alignment = alignment;
            _x.margin = margin;
            return _x;
        }
    }

    private AddHeader _copy() {
        AddHeader _x = new AddHeader();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.name = name;
        _x.fontColor = fontColor;
        _x.fontSize = fontSize;
        _x.text = text;
        _x.alignment = alignment;
        _x.margin = margin;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AddHeader[");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("fontColor=");
        b.append(this.fontColor);
        b.append(", ");
        b.append("fontSize=");
        b.append(this.fontSize);
        b.append(", ");
        b.append("text=");
        b.append(this.text);
        b.append(", ");
        b.append("alignment=");
        b.append(this.alignment);
        b.append(", ");
        b.append("margin=");
        b.append(this.margin);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
